@@ -54,18 +54,16 @@ void SharedKvtmlFilesPrivate::rescan()
     this->m_filesByLang.clear();
     this->m_fileList.clear();
 
-    QStringList locales;
-
     // Get all kvtml paths
     QStringList nameFilter;
     nameFilter.append(QStringLiteral("*.kvtml"));
-    QStringList dataPaths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("apps/kvtml"), QStandardPaths::LocateDirectory);
-    Q_FOREACH (const QString &path, dataPaths) {
+    const QStringList dataPaths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("apps/kvtml"), QStandardPaths::LocateDirectory);
+    for (const QString &path : dataPaths) {
         qDebug() << "Checking path " << path << " for kvtml files";
-        QStringList locales = QDir( path ).entryList( QDir::Dirs | QDir::NoDotAndDotDot, QDir::Name );
-        Q_FOREACH (const QString &locale, locales) {
-            QStringList files = QDir( path + '/' + locale ).entryList(nameFilter, QDir::Files );
-            Q_FOREACH (const QString &filename, files) {
+        const QStringList locales = QDir( path ).entryList( QDir::Dirs | QDir::NoDotAndDotDot, QDir::Name );
+        for (const QString &locale : locales) {
+            const QStringList files = QDir( path + '/' + locale ).entryList(nameFilter, QDir::Files );
+            for (const QString &filename : files) {
                 QString filePath = path + '/' + locale + '/' + filename;
                 this->m_fileList << filePath;
                 this->m_filesByLang[locale].append( filePath );
@@ -77,7 +75,7 @@ void SharedKvtmlFilesPrivate::rescan()
     for ( int i = 0; i < this->m_fileList.size(); ++i ) {
 
         // open the file
-        doc->open( QUrl::fromLocalFile( this->m_fileList[i] ) );
+        doc->open( QUrl::fromLocalFile( this->m_fileList[i] ),  KEduVocDocument::FileIgnoreLock );
 
         // add it's title to the title list
         this->m_titleList.append( doc->title() );
@@ -141,11 +139,11 @@ void SharedKvtmlFiles::sortDownloadedFiles()
 {
     QStringList nameFilter;
     nameFilter.append(QStringLiteral("*.kvtml"));
-    QStringList dataPaths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("apps/kvtml"), QStandardPaths::LocateDirectory);
+    const QStringList dataPaths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("apps/kvtml"), QStandardPaths::LocateDirectory);
     QStringList unsortedFiles;
-    Q_FOREACH (const QString &path, dataPaths) {
-        QStringList files = QDir( path ).entryList(nameFilter, QDir::Files | QDir::NoDotAndDotDot );
-        Q_FOREACH (const QString &filename, files) {
+    for (const QString &path : dataPaths) {
+        const QStringList files = QDir( path ).entryList(nameFilter, QDir::Files | QDir::NoDotAndDotDot );
+        for (const QString &filename : files) {
             unsortedFiles.append( path + '/' + filename);
         }
     }
@@ -176,9 +174,9 @@ void SharedKvtmlFiles::sortDownloadedFiles()
 
     nameFilter = QStringList(QStringLiteral("*.txt"));
     QStringList khangmanFiles;
-    Q_FOREACH (const QString &path, dataPaths) {
-        QStringList files = QDir( path ).entryList(nameFilter, QDir::Files );
-        Q_FOREACH (const QString &filename, files) {
+    for (const QString &path : dataPaths) {
+        const QStringList files = QDir( path ).entryList(nameFilter, QDir::Files );
+        for (const QString &filename : files) {
             khangmanFiles.append( path + '/' + filename);
         }
     }
@@ -186,7 +184,7 @@ void SharedKvtmlFiles::sortDownloadedFiles()
     // move khangman files into
     while ( !khangmanFiles.isEmpty() ) {
         QUrl fileUrl( QUrl::fromLocalFile( khangmanFiles.first() ) );
-        QUrl destDir = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + "/khangman/data/");
+        QUrl destDir = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + "/khangman/data/");
         // do this better with KStandardDirs stuff
         KIO::move( fileUrl, destDir);
         khangmanFiles.removeFirst();
